form argument gives considerable flexibility in the type of
plot specification. A conditioning expression (on the right side of a
| operator) always implies that different panels are used for
each level of the conditioning factor, according to a Trellis
display. The expression on the right hand side of the formula, before
a | operator, must evaluate to a data frame with at least two
columns. If the data frame has two columns, a scatter plot of the two
variables is displayed (the Trellis function xyplot is
used). Otherwise, if more than two columns are present, a scatter plot
matrix with pairwise scatter plots of the columns in the data frame is
displayed (the Trellis function splom is used).
"pairs"(x, form, label, id, idLabels, grid, ...)"lme", representing
a fitted linear mixed-effects model.x can be referenced. In addition, x itself
can be referenced in the formula using the symbol
".". Conditional expressions on the right of a |
operator can be used to define separate panels in a Trellis
display. The expression on the right hand side of form, and to
the left of the | operator, must evaluate to a data frame with
at least two columns. Default is ~ coef(.) , corresponding to
a pairs plot of the coefficients evaluated at the innermost level of
nesting.idLabels. If given as a
one-sided formula, its right hand side must evaluate to a logical,
integer, or character vector which is used to identify points in the
plot. If missing, no points are identified.id. If given as a
one-sided formula, its right hand side must evaluate to a vector
which is converted to character and used to label the identified
points. Default is the innermost grouping factor.
FALSE.lme,
pairs.compareFits,
pairs.lmList,
xyplot,
splom
fm1 <- lme(distance ~ age, Orthodont, random = ~ age | Subject)
# scatter plot of coefficients by gender, identifying unusual subjects
pairs(fm1, ~coef(., augFrame = TRUE) | Sex, id = 0.1, adj = -0.5)
# scatter plot of estimated random effects
## Not run:
# pairs(fm1, ~ranef(.))
# ## End(Not run)
Run the code above in your browser using DataLab