resType
an optional character string specifying the type of
residuals to be used. If "response", the "raw" residuals
(observed - fitted) are used; else, if "pearson", the
standardized residuals (raw residuals divided by the corresponding
standard errors) are used; else, if "normalized", the
normalized residuals (standardized residuals pre-multiplied by the
inverse square-root factor of the estimated error correlation
matrix) are used. Partial matching of arguments is used, so only the
first character needs to be provided. Defaults to "pearson".
form
an optional one sided formula of the form ~ t, or
~ t | g, specifying a time covariate t and, optionally, a
grouping factor g. The time covariate must be integer
valued. When a grouping factor is present in
form, the autocorrelations are calculated using residual pairs
within the same group. Defaults to ~ 1, which corresponds to
using the order of the observations in the data as a covariate, and
no groups.