# S3 method for lme
fitted(object, level, asList, …)"lme", representing
a fitted linear mixed-effects model.object. Level
values increase from outermost to innermost grouping, with
level zero corresponding to the population fitted values. Defaults to
the highest or innermost level of grouping.TRUE and a single
value is given in level, the returned object is a list with
the fitted values split by groups; else the returned value is
either a vector or a data frame, according to the length of
level. Defaults to FALSE.level, the
returned value is either a list with the fitted values split by groups
(asList = TRUE) or a vector with the fitted values
(asList = FALSE); else, when multiple grouping levels are
specified in level, the returned object is a data frame with
columns given by the fitted values at different levels and the
grouping factors. For a vector or data frame result the
napredict method is applied.lme, residuals.lmefm1 <- lme(distance ~ age + Sex, data = Orthodont, random = ~ 1)
fitted(fm1, level = 0:1)
Run the code above in your browser using DataLab