level
an optional integer vector giving the level(s) of grouping
to be used in extracting the fitted values from object. Level
values increase from outermost to innermost grouping, with
level zero corresponding to the population fitted val
asList
an optional logical value. If TRUE and a single
value is given in level, the returned object is a list with
the fitted values split by groups; else the returned value is
either a vector or a data frame, according to the