Learn R Programming

nlme (version 3.1-130)

fixef.lmList: Extract lmList Fixed Effects

Description

The average of the coefficients corresponding to the lm components of object is calculated.

Usage

"fixef"(object, ...)

Arguments

object
an object inheriting from class "lmList", representing a list of lm objects with a common model.
...
some methods for this generic require additional arguments. None are used in this method.

Value

a vector with the average of the individual lm coefficients in object.

See Also

lmList, random.effects.lmList

Examples

Run this code
fm1 <- lmList(distance ~ age | Subject, Orthodont)
fixed.effects(fm1)

Run the code above in your browser using DataLab