getCovariate.data.frame: Extract Data Frame Covariate
Description
The right hand side of form, stripped of any conditioning
expression (i.e. an expression following a | operator), is
evaluated in object.Usage
## S3 method for class 'data.frame':
getCovariate(object, form, data)
Value
the value of the right hand side of form, stripped of
any conditional expression, evaluated in object.