object are obtained, using
a normal approximation to the distribution of the (restricted)
maximum likelihood estimators (the estimators are assumed to have a
normal distribution centered at the true parameter values and with
covariance matrix equal to the negative inverse Hessian matrix of the
(restricted) log-likelihood evaluated at the estimated parameters).
Confidence intervals are obtained in an unconstrained scale first,
using the normal approximation, and, if necessary, transformed to the
constrained scale.# S3 method for gls
intervals(object, level, which, …)"gls", representing
a generalized least squares fitted linear model."all" for all parameters,
"var-cov" for the variance-covariance parameters only, and
"coef" for the linear model coefficients only. Defaults to
"all".lower, est., and upper
representing respectively lower confidence limits, the estimated
values, and upper confidence limits for the parameters. Possible
components are:
which
is not equal to "var-cov".which is not equal to "coef" and a
correlation structure is used in object.which is not equal to "coef" and a variance function
structure is used in object.gls, intervals,
print.intervals.glsfm1 <- gls(follicles ~ sin(2*pi*Time) + cos(2*pi*Time), Ovary,
correlation = corAR1(form = ~ 1 | Mare))
intervals(fm1)
Run the code above in your browser using DataLab