control argument to the nlme function.
nlmeControl(maxIter, pnlsMaxIter, msMaxIter, minScale, tolerance, niterEM, pnlsTol, msTol, returnObject, msVerbose, gradHess, apVar, .relStep, minAbsParApVar = 0.05, opt = c("nlminb", "nlm"), natural = TRUE, sigma = NULL, ...)nlme
optimization algorithm. Default is 50.PNLS optimization step inside the nlme
optimization. Default is 7.nlm optimization step inside the nlme
optimization. Default is 50.PNLS step.
Default 0.001.nlme algorithm. Default is 1e-6.PNLS
step. Default is 1e-3.nlm,
passed as the gradtol argument to the function (see
documentation on nlm). Default is 1e-7. FALSE.trace argument to
nlm (see documentation on that function). Default is
FALSE.nlm optimization. This option is only available
when the correlation structure (corStruct) and the variance
function structure (varFunc) have no "varying" parameters and
the pdMat classes used in the random effects structure are
pdSymm (general positive-definite), pdDiag (diagonal),
pdIdent (multiple of the identity), or
pdCompSymm (compound symmetry). Default is TRUE.TRUE..Machine$double.eps^(1/3).0.05.pdNatural
parametrization should be used for general positive-definite matrices
(pdSymm) in reStruct, when the approximate covariance
matrix of the estimators is calculated. Default is TRUE.NULL, as by default, or 0, sigma is estimated.nlminb, where used (eval.max and those from
abs.tol down).nlme, nlm, optim,
nlmeStruct# decrease the maximum number iterations in the ms call and
# request that information on the evolution of the ms iterations be printed
nlmeControl(msMaxIter = 20, msVerbose = TRUE)
Run the code above in your browser using DataLab