nlmeObject: Fitted nlme Object
Description
An object returned by the nlme function, inheriting from class
"nlme", also inheriting from class "lme", and representing a
fitted nonlinear mixed-effects model. Objects of this class have
methods for the generic functions anova, coef,
fitted, fixed.effects, formula, getGroups,
getResponse, intervals, logLik, pairs,
plot, predict, print, random.effects,
residuals, summary, and update.Value
The following components must be included in a legitimate "nlme"
object.