formula(data)
are used together with model to construct the nonlinear model
formula. This is used in the nls calls and, because a
selfStarting model function can calculate initial estimates for its
parameters from the data, no starting estimates need to be provided.
"nlsList"(model, data, start, control, level, subset, na.action = na.fail, pool = TRUE, warn.nls = NA)"selfStart" model function, which calculates
initial estimates for the model parameters from data.model. Because no grouping factor can be specified in
model, data must inherit from class
"groupedData".
model. It is passed as the
start argument to each nls call and is required when
the nonlinear function in model does not inherit from class
selfStart.
control
argument to nls. Defaults to an empty list.
data that should be used in the fit. This can be a logical
vector, or a numeric vector indicating which observation numbers are
to be included, or a character vector of the row names to be
included. All observations are included by default.NAs. The default action (na.fail) causes
nlsList to print an error message and terminate if there are any
incomplete observations.
nls objects with as many components as the number of
groups defined by the grouping factor. A NULL value is assigned
to the components corresponding to clusters for which the nls
algorithm failed to converge. Generic functions such as coef,
fixed.effects, lme, pairs, plot,
predict, random.effects, summary, and
update have methods that can be applied to an nlsList
object.
selfStart, groupedData,
nls, nlsList,
nlme.nlsList, nlsList.formula
fm1 <- nlsList(SSasympOff, CO2)
summary(fm1)
Run the code above in your browser using DataLab