lm component of
object and arranged into a list with as many components as
object, or combined into a single vector.
"residuals"(object, type, subset, asList, ...)"lmList", representing
a list of lm objects with a common model.
lm components of object from which the residuals
are to be extracted. Default is NULL, in which case all
components are used.
"response" for the
"raw" residuals (observed - fitted), "pearson" for the
standardized residuals (raw residuals divided by the estimated
residual standard error) using different standard errors for each
lm fit, and "pooled.pearson" for the standardized
residuals using a pooled estimate of the residual standard
error. Partial matching of arguments is used, so only the first
character needs to be provided. Defaults to "response".
TRUE, the returned
object is a list with the residuals split by groups; else the
returned value is a vector. Defaults to FALSE.
lm
component of object, or a vector with the residuals for all
lm components of object.
lmList, fitted.lmListfm1 <- lmList(distance ~ age | Subject, Orthodont)
residuals(fm1)
Run the code above in your browser using DataLab