summary.gls: Summarize a Generalized Least Squares gls Object
Description
Additional information about the linear model fit represented
by object is extracted and included as components of
object.
Usage
"summary"(object, verbose, ...)
Arguments
object
an object inheriting from class "gls", representing
a generalized least squares fitted linear model.
verbose
an optional logical value used to control the amount of
output when the object is printed. Defaults to FALSE.
...
some methods for this generic require additional
arguments. None are used in this method.
Value
an object inheriting from class summary.gls with all components
included in object (see glsObject for a full
description of the components) plus the following components: