Learn R Programming

nlme (version 3.1-130)

summary.lmList: Summarize an lmList Object

Description

The summary.lm method is applied to each lm component of object to produce summary information on the individual fits, which is organized into a list of summary statistics. The returned object is suitable for printing with the print.summary.lmList method.

Usage

"summary"(object, pool, ...)

Arguments

object
an object inheriting from class "lmList", representing a list of lm fitted objects.
pool
an optional logical value indicating whether a pooled estimate of the residual standard error should be used. Default is attr(object, "pool").
...
some methods for this generic require additional arguments. None are used in this method.

Value

a list with summary statistics obtained by applying summary.lm to the elements of object, inheriting from class summary.lmList. The components of value are:

See Also

lmList, summary

Examples

Run this code
fm1 <- lmList(distance ~ age | Subject, Orthodont)
summary(fm1)

Run the code above in your browser using DataLab