object is extracted and included as components of
object. The returned object has a print and a
coef method, the latter returning the coefficient's
tTtable.# S3 method for lme
summary(object, adjustSigma, verbose, …)
# S3 method for summary.lme
print(x, verbose = FALSE, …)"lme", representing
a fitted linear mixed-effects model.TRUE and the
estimation method used to obtain object was maximum
likelihood, the residual standard error is multiplied by
\(\sqrt{n_{obs}/(n_{obs} - n_{par})}\),
converting it to a REML-like estimate. This argument is only used
when a single fitted object is passed to the function. Default is
TRUE.print.summary.lme method. Defaults to
FALSE.print method."summary.lme" object.summary.lme with all components
included in object (see lmeObject for a full
description of the components) plus the following components:
Value,
Std. Error, DF, t-value, and p-value
representing respectively the fixed effects estimates, their
approximate standard errors, the denominator degrees of freedom, the
ratios between the estimates and their standard errors, and the
associated p-value from a t distribution. Rows correspond to the
different fixed effects.lme fit, a vector with the minimum, first quartile, median, third
quartile, and maximum of the innermost grouping level residuals
distribution; else the innermost grouping level residuals.object.object.AIC, BIC,
lme.fm1 <- lme(distance ~ age, Orthodont, random = ~ age | Subject)
(s1 <- summary(fm1))
## Not run: coef(s1) # the (coef | Std.E | t | P-v ) matrix
Run the code above in your browser using DataLab