Additional information about the linear mixed-effects fit represented
by object is extracted and included as components of
object. The returned object has a print and a
coef method, the latter returning the coefficient's
tTtable.
an object inheriting from class "lme", representing
a fitted linear mixed-effects model.
adjustSigma
an optional logical value. If TRUE and the
estimation method used to obtain object was maximum
likelihood, the residual standard error is multiplied by
$sqrt(nobs/(nobs - npar))$,
converting it to a REML-like estimate. This argument is only used
when a single fitted object is passed to the function. Default is
TRUE.
verbose
an optional logical value used to control the amount of
output in the print.summary.lme method. Defaults to
FALSE.
...
additional optional arguments passed to methods, mainly
for the print method.
x
a "summary.lme" object.
Value
an object inheriting from class summary.lme with all components
included in object (see lmeObject for a full
description of the components) plus the following components: