The summary function is applied to each nls component of
object to produce summary information on the individual fits,
which is organized into a list of summary statistics. The returned
object is suitable for printing with the print.summary.nlsList
method.
Usage
"summary"(object, ...)
Arguments
object
an object inheriting from class "nlsList",
representing a list of nls fitted objects.
...
optional arguments to the summary.lmList method.
One such optional argument is pool, a logical value indicating
whether a pooled estimate of the residual standard error should be
used. Default is attr(object, "pool").
Value
a list with summary statistics obtained by applying summary
to the elements of object, inheriting from class
summary.nlsList. The components of value are: