varClasses: Variance Function Classes
Description
Standard classes of variance function structures (varFunc)
available in the nlme package. Covariates included in the
variance function, denoted by variance covariates, may involve
functions of the fitted model object, such as the fitted values and
the residuals. Different coefficients may be assigned to the levels of
a classification factor.
Value
Available standard classes:
References
Pinheiro, J.C., and Bates, D.M. (2000) "Mixed-Effects Models
in S and S-PLUS", Springer.